===========
Django Suit
===========

**Modern theme for Django admin interface**.

Django Suit is alternative theme/skin/extension for `Django <http://www.djangoproject.com>`_ administration interface.

* Project home: http://djangosuit.com/
* Live demo: http://djangosuit.com/admin/


License
=======

* Django Suit is licensed under `Creative Commons Attribution-NonCommercial 3.0 <http://creativecommons.org/licenses/by-nc/3.0/>`_ license.
* Licence and pricing: http://djangosuit.com/pricing/


Docs & Support
==============

* Documentation: http://django-suit.readthedocs.org/
* Support: http://djangosuit.com/support/
* `Demo app <http://djangosuit.com/admin/>`_ repository is here: `django-suit-examples <https://github.com/darklow/django-suit-examples>`_
* IRC Channel: Feel free to join us at ``#django-suit`` on ``irc.freenode.net`` for a chat
* Follow `on Twitter <http://twitter.com/DjangoSuit>`_ to get latest news

Changelog
=========

See `CHANGELOG.rst <https://github.com/darklow/django-suit/blob/develop/CHANGELOG.rst>`_.


Contributing
============

See `Contributing documentation <http://django-suit.readthedocs.org/en/develop/contributing.html>`_


Build Status
============

Django Suit uses Travis CI to perform tests on different Django and Python versions.

Tested using Python: 2.5-3.4. Django: 1.4-1.10. Develop / Master:

.. |develop| image:: https://travis-ci.org/darklow/django-suit.png?branch=develop
   :alt: Build Status - develop branch
   :target: http://travis-ci.org/darklow/django-suit

.. |master| image:: https://travis-ci.org/darklow/django-suit.png?branch=master
   :alt: Build Status - master branch
   :target: http://travis-ci.org/darklow/django-suit

|develop| |master|


Preview
=======

.. image:: https://raw.github.com/darklow/django-suit/develop/docs/_static/img/django-suit.png
   :alt: Django Suit Preview
   :target: http://djangosuit.com/admin/


v2.0-dev
========

Check out new v2.0-dev version notes: https://github.com/darklow/django-suit/issues/475
